==> nextcloud-24.0.7.tar.bz2: nextcloud/apps/circles/l10n/nl.js <==
OC.L10N.register(
    "circles",
    {
    "Circles" : "Kringen",
    "Circles' files" : "Kringbestanden",
    "Select circles to filter by" : "Selecteer kring om te filteren",
    "No circles found" : "Geen kringen gevonden",
    "Please select circles to filter by" : "Selecteer kringen om te filteren",
    "No files found for the selected circles" : "Geen bestanden gevonden voor de geselecteerde kringen",
    "You created the circle {circle}" : "Je hebt de kring {circle} gecreëerd",
    "{author} created the circle {circle}" : "{author} maakte de {circle} kring",
    "You deleted {circle}" : "Je hebt {circle} verwijderd",
    "{author} deleted {circle}" : "{author} verwijderde {circle}",
    "You linked {group} to {circle}" : "Je koppelde {group} met {circle}",
    "{group} has been linked to {circle} by {author}" : "{group} is gekoppeld met {circle} door {author}",
    "You unlinked {group} from {circle}" : "Je ontkoppelde {group} met {circle}",
    "{group} has been unlinked from {circle} by {author}" : "{group} is ontkoppeld met {circle} door {author}",
    "You changed the level of the linked group {group} in {circle} to %1$s" : "Je veranderde het niveau van de gekoppelde groep {group} in {circle} naar %1$s",
    "{author} changed the level of the linked group {group} in {circle} to %1$s" : "{author} veranderde het niveau van de gekoppelde groep {group} in {circle} naar %1$s",
    "You sent a request to link {circle} with {remote}" : "Je verzond een {circle} link verzoek met met {remote}",
    "{author} sent a request to link {circle} with {remote}" : "{author} verzonden een {circle} link verzoek met {remote}",
    "{remote} requested a link with {circle}" : "{remote} verzocht een link verzoek met {circle}",
    "The request to link {circle} with {remote} has been rejected" : "Het {circle} link verzoek met {remote} is afgewezen",
    "The request to link {remote} with {circle} has been canceled remotely" : "Het {remote} link verzoek met {circle} is op afstand afgesloten",
    "The request to link {circle} with {remote} has been accepted" : "Het {circle} link verzoek met {remote} is geaccepteerd",
    "You dismissed the request to link {remote} with {circle}" : "Je hebt het {remote} link verzoek met {circle} afgewezen",
    "{author} dismissed the request to link {remote} with {circle}" : "{author} heeft het {remote} link verzoek met {circle} afgewezen",
    "You canceled the request to link {circle} with {remote}" : "Je hebt het {circle} link verzoek met {remote} afgewezen",
    "{author} canceled the request to link {circle} with {remote}" : "{author} heeft het {circle} link verzoek met {remote} afgewezen",
    "You accepted the request to link {remote} with {circle}" : "Je accepteerde het {remote} link verzoek met {circle}",
    "{author} accepted the request to link {remote} with {circle}" : "{author} accepteerde het {remote} link verzoek met {circle}",
    "A link between {circle} and {remote} is now up and running" : "De link tussen {circle} en {remote} is nu verbonden",
    "The link between {circle} and {remote} has been shutdown remotely" : "De link tussen {circle} en {remote} is op afstand afgesloten",
    "You closed the link between {circle} and {remote}" : "Je sloot de link tussen {circle} en {remote}",
    "{author} closed the link between {circle} and {remote}" : "{author} sloot de link tussen {circle} en {remote}",
    "You joined {circle}" : "Je bent lid geworden van {circle}",
    "{member} joined {circle}" : "{member} werd lid van {circle}",
    "You accepted the invitation to join {circle}" : "Je hebt de uitnodiging voor {circle} geaccepteerd",
    "{member} accepted the invitation to join {circle}" : "{member} heeft de uitnodiging voor {circle} geaccepteerd",
    "You added {member} as member to {circle}" : "Jij hebt {member} aan {circle} toegevoegd",
    "You have been added as member to {circle} by {author}" : "Je bent door {author} als lid tot {circle} toegevoegd",
    "{member} has been added as member to {circle} by {author}" : "{member} is door {author} als lid tot {circle} toegevoegd",
    "You added {external} to {circle}" : "Je hebt {external} toegevoegd aan {circle}",
    "{external} has been added to {circle} by {author}" : "{external} is toegevoegd aan {circle} door {author}",
    "You accepted {member}'s request to join {circle}" : "Je accepteerde {member}'s verzoek op lid te worden van {circle}",
    "Your request to join {circle} has been accepted by {author}" : "Je verzoek om lid te worden van {circle} is door {author} geaccepteerd",
    "{member}'s request to join {circle} has been accepted by {author}" : "{member}'s verzoek om lid te worden van {circle} is door {author} geaccepteerd",
    "You left {circle}" : "Je hebt {circle} verlaten",
    "{member} left {circle}" : "{member} verliet {circle}",
    "You declined the invitation to join {circle}" : "Je hebt de uitnodiging om lid te worden van {circle} afgewezen",
    "{member} declined an invitation to join {circle}" : "{member} heeft de uitnodiging om lid te worden van {circle} afgewezen",
    "You cancelled your request to join {circle}" : "Je hebt je verzoek om lid te worden van {circle} ingetrokken",
    "{member} cancelled his request to join {circle}" : "{member} trok verzoek om lid te worden van {circle} weer in",
    "You removed {member} from {circle}" : "Je hebt {member} van {circle} verwijderd",
    "You have been removed from {circle} by {author}" : "Je werd van {circle} door {author} verwijderd",
    "{member} has been removed from {circle} by {author}" : "{member} is van {circle} door {author} verwijderd",
    "You removed {external} from {circle}" : "Je hebt {external} verwijderd van {circle}",
    "{external} has been removed from {circle} by {author}" : "{external} is door {author} verwijderd van {circle} ",
    "You cancelled {member}'s invitation to join {circle}" : "Je hebt de uitnodiging voor {member} om lid te worden van {circle} ingetrokken",
    "Your invitation to join {circle} has been cancelled by {author}" : "Je uitnodiging om lid te worden van {circle} is door {author} ingetrokken",
    "{author} cancelled {member}'s invitation to join {circle}" : "{author} heeft de uitnodiging voor {member} om lid te worden van {circle} ingetrokken",
    "You dismissed {member}'s request to join {circle}" : "Je het het verzoek van {member}'s om lid te worden van {circle} afgewezen",
    "Your request to join {circle} has been dismissed by {author}" : "Je verzoek om bij {circle} aan te sluiten is door {author} afgewezen",
    "{member}'s request to join {circle} has been dismissed by {author}" : "{member}'s verzoek om lid te worden van {circle} is door {author} afgewezen",
    "You invited {member} to join {circle}" : "Je nodigde {member} uit om lid te worden van {circle}",
    "You have been invited to join {circle} by {author}" : "Je bent uitgenodigd om lid te worden van {circle} door {author}",
    "{member} has been invited to join {circle} by {author}" : "{member} is uitgenodigd om lid te worden van {circle} door {author}",
    "You changed {member}'s level in {circle} to %1$s" : "Je veranderde {member}'s niveau in {circle} naar %1$s",
    "{author} changed your level in {circle} to %1$s" : "{author} veranderde je niveau in {circle} naar %1$s",
    "{author} changed {member}'s level in {circle} to %1$s" : "{author} veranderde {member}'s niveau van {circle} naar %1$s",
    "You sent a request to join {circle}" : "Je verzoek gestuurd om lid te worden van {circle}",
    "{member} sent a request to join {circle}" : "{member} verzond een verzoek om lid te worden van {circle}",
    "You are the new owner of {circle}" : "Je bent de nieuwe eigenaar van {circle}",
    "{member} is the new owner of {circle}" : "{member} is de nieuwe eigenaar van {circle}",
    "On events happening in a <strong>Circle</strong> of which you are a member" : "Over gebeurtenissen in een <strong>Kring</strong> waarvan je lid bent",
    "Any important event in a <strong>Circle</strong> you are moderating" : "Belangrijke gebeurtenissen in <strong>Kring</strong> die je modereert",
    "On global events happening in any <strong>Circle</strong>" : "Over globale afspraken die gebereuren binnen een <strong>Kring</strong>",
    "Single" : "Alleen",
    "Personal" : "Persoonlijk",
    "System" : "Systeem",
    "Visible" : "Zichtbaar",
    "Open" : "Open",
    "Invite" : "Uitnodigen",
    "Join Request" : "Deelnameverzoek",
    "Friends" : "Vrienden",
    "Password Protected" : "Wachtwoordbeveiligd",
    "No Owner" : "Geen eigenaar",
    "Hidden" : "Verborgen",
    "Backend" : "Backend",
    "Local" : "Lokaal",
    "Root" : "Root",
    "Circle Invite" : "Kringuitnodiging",
    "Federated" : "Gefedereerd",
    "Mount point" : "Aankoppelpunt",
    "Nextcloud Group" : "Nextcloud Groep",
    "Email Address" : "E-mailadres",
    "Contact" : "Contact",
    "Circle" : "Kring",
    "Nextcloud App" : "Nextcloud App",
    "Member" : "Lid",
    "Moderator" : "Moderator",
    "Admin" : "Beheerder",
    "Owner" : "Eigenaar",
    "%s shared »%s« with you." : "%sheeft \"%s\" met je gedeeld.",
    "%s shared »%s« with \"%s\"." : "%s deelde \"%s\" met \"%s\".",
    "%s on %s" : "%s op  %s",
    "%1$s shared »%2$s« with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s heeft \"%2$s\" met je gedeeld.\nJe moet al een aparte e-mail hebben ontvangen met een link om er te komen.\n",
    "%1$s shared »%2$s« with you. You should have already received a separate email with a link to access it." : "%1$s heeft \"%2$s\" met je gedeeld. Je moet al een aparte e-mail hebben ontvangen met een link om er te komen.",
    "Password to access »%1$s« shared to you by %2$s" : "Wachtwoord voor toegang tot \"%1$s\" met jou gedeeld door %2$s",
    "Password to access »%s«" : "Wachtwoord voor toegang \"%s\"",
    "It is protected with the following password:" : "Het is beveiligd met het volgende wachtwoord:",
    "%1$s via %2$s" : "%1$s via %2$s",
    "Click the button below to open it." : "Klik op de button hieronder om te openen.",
    "Open »%s«" : "Open \"%s\"",
    "%1$s shared multiple files with you.\nYou should have already received a separate email with a link to access them.\n" : "%1$s heeft verschillende bestanden met je gedeeld.\nJe moet al een aparte e-mail hebben ontvangen met een link om er te komen.\n",
    "%1$s shared multiple files with you. You should have already received a separate email with a link to access them." : "%1$s heeft verschillende bestanden met je gedeeld. Je moet al een aparte e-mail hebben ontvangen met een link om er te komen.",
    "Password to access files shared to you by %1$s" : "Wachtwoord voor toegang tot bestanden met jou gedeeld door %1$s",
    "Password to access files" : "Wachtwoord voor toegang tot bestanden",
    "%s shared multiple files with \"%s\"." : "%s deelde meerdere bestanden met \"%s\".",
    "%s shared multiple files with you." : "%s deelde meerdere bestanden met jou.",
    "Boot up" : "Opstarten",
    "Initialisation Nextcloud" : "Initialisatie Nextcloud",
    "Initialisation Circles App" : "Initialisatie Circles App",
    "Fresh installation status" : "Nieuwe installatiestatus",
    "Building Local Database" : "Aanmaken lokale database",
    "Testing Basic Circle Creation" : "Testen basis kringcreatie",
    "Adding local users and moderators" : "Toevoegen lokale gebruikers en moderatoren",
    "Circle not found" : "Kring niet gevonden",
    "Circle not found " : "Kring niet gevonden",
    "A circle with that name exists" : "Er bestaat al een kring met deze naam",
    "You cannot use the Circles Application until your administrator has allowed at least one type of circles" : "De beheerder dient minimaal een kring te maken voordat je de kring-app kan gebruiken.",
    "This member does not exist" : "Dit lid bestaat niet",
    "Federated link not found" : "Gefedereerde link is niet gevonden",
    "This feature is not available for personal circles" : "Deze functie is niet beschikbaar voor persoonlijke kringen",
    "The circle is not federated" : "De kring is niet gefedereerd",
    "You cannot join this circle" : "Je kunt niet lid worden van deze kring",
    "This member is not a moderator" : "Dit lid is geen moderator",
    "Insufficient privileges" : "Onvoldoende rechten",
    "This member is the owner of the circle" : "Dit lid is de eigenaar van de kring",
    "Level cannot be changed for this type of member" : "Het niveau van dit type lid kan niet veranderd worden.",
    "You are already a member of this circle" : "Je bent al lid van deze kring",
    "You have been blocked from this circle" : "Je bent geblokkeerd van deze kring",
    "%s (Circle owned by %s)" : "%s (kring is eigendom van %s)",
    "You are now a member of the Circle \"%2$s\"" : "Je bent nu lid van Kring \"%2$s\"",
    "You have been invited by %1$s into the Circle \"%2$s\"" : "Je bent uitgenodigd door %1$sin Kring voor  \"%2$s\"",
    "%1$s sent a request to be a member of the Circle \"%2$s\"" : "%1$s verstuurde een lidmaatschapsverzoek voor Kring \"%2$s\"",
    "Accept" : "Accepteren",
    "Refuse" : "Weigeren",
    "Leave the circle" : "Verlaat de kring",
    "%s" : "%s",
    "Personal Circle" : "Persoonlijke kring",
    "%s owned by %s" : "%s is eigendom van %s",
    "You need a specify a type of circle" : "Een specifieke kring type is benodigd",
    "This member is not the owner of the circle" : "Dit lid is niet de eigenaar van de kring",
    "This member is not an admin of the circle" : "Dit lid is geen beheerder van de kring",
    "Group contains too many members" : "De groep bevat te veel leden",
    "This group does not exist" : "Deze groep bestaat niet",
    "This group is already linked to the circle" : "Deze groep is al verbonden met de kring",
    "You cannot edit level in a personal circle" : "Je kan het niveau van een persoonlijke kring niet bewerken",
    "Group cannot be set as owner of a circle" : "Een groep kan geen kring eigenaar zijn",
    "now" : "nu",
    "Email format is not valid" : "E-mailformaat niet geldig",
    "This contact is not available" : "Deze contact is niet beschikbaar",
    "You have no permission to create a new circle" : "U heeft geen machtiging om een nieuwe kring aan te maken",
    "%s shared a file with \"%s\"." : "%s deelde een bestand met \"%s\".",
    "%s shared a file with you." : "%s heeft een bestand met u gedeeld",
    "%1$s shared some content with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s heeft enige informatie met je gedeeld.\nJe moet al een aparte e-mail hebben ontvangen met een link om er te komen.\n",
    "%1$s shared some content with you. You should have already received a separate email with a link to access it." : "%1$s heeft enige informatie met je gedeeld.\nJe moet al een aparte e-mail hebben ontvangen met een link om er te komen.",
    "Password to access content" : "Wachtwoord voor toegang tot info",
    "This item is already shared with this circle" : "Dit object is al gedeeld met deze kring",
    "Could not find share" : "De gedeelde folder kan niet worden gevonden",
    "Bring cloud-users closer together." : "Breng cloudgebruikers dichter bij elkaar.",
    "No files in here" : "Hier geen bestanden",
    "No entries found in this folder" : "Niets in deze map gevonden",
    "Name" : "Naam",
    "Size" : "Omvang",
    "Modified" : "Gewijzigd",
    "Nextcloud User" : "Nextcloud gebruiker",
    "This user is already a member of the circle" : "Deze gebruiker is al lid van de kring",
    "The user is already a member of this circle" : "De gebruiker is al lid van deze kring",
    "The user has already been invited into this circle" : "De gebruiker is al uitgenodigd voor deze kring",
    "This user does not exist" : "Deze gebruiker bestaat niet",
    "Circles allows your users to create their own groups of users/colleagues/friends.\nThose groups of users (or \"circles\") can then be used by any other app for sharing purpose." : "Met kringen kunnen gebruikers hun eigen groepen gebruikers / collega's / vrienden maken.\nDie groepen gebruikers (of \"kringen\") kunnen vervolgens door elke andere app worden gebruikt om te delen."
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-32.0.2.tar.bz2: nextcloud/apps/circles/l10n/nl.js <==
OC.L10N.register(
    "circles",
    {
    "You created the team {circle}" : "Je hebt het team {circle} aangemaakt",
    "{author} created the team {circle}" : "{author} heeft het team {circle} aangemaakt",
    "You deleted {circle}" : "Je hebt {circle} verwijderd",
    "{author} deleted {circle}" : "{author} verwijderde {circle}",
    "You made {member} join {circle}" : "Je hebt {member} toegevoegd aan {circle}",
    "{author} made {member} join {circle}" : "{author} heeft {member} toegevoegd aan {circle}",
    "You added team {member} as member to {circle}" : "Je hebt team {member} als lid toegevoegd aan {circle}",
    "{author} added team {member} as member to {circle}" : "{author} heeft team {member} als lid toegevoegd aan {circle}",
    "You made {member} leave {circle}" : "JIj hebt {member} {circle} laten verlaten",
    "{author} made {member} leave {circle}" : "{author}heeft {member} {circle} laten verlaten",
    "You removed {member} from {circle}" : "Je hebt {member} verwijderd van {circle}",
    "{author} removed {member} from {circle}" : "{author} heeft {member} verwijderd van {circle}",
    "You joined {circle}" : "Je bent lid geworden van {circle}",
    "{member} joined {circle}" : "{member} werd lid van {circle}",
    "You accepted the invitation to join {circle}" : "Je hebt de uitnodiging voor {circle} geaccepteerd",
    "{member} accepted the invitation to join {circle}" : "{member} heeft de uitnodiging voor {circle} geaccepteerd",
    "You added {member} as member to {circle}" : "Jij hebt {member} aan {circle} toegevoegd",
    "You have been added as member to {circle} by {author}" : "Je bent door {author} als lid tot {circle} toegevoegd",
    "{member} has been added as member to {circle} by {author}" : "{member} is door {author} als lid tot {circle} toegevoegd",
    "You added {external} to {circle}" : "Je hebt {external} toegevoegd aan {circle}",
    "{external} has been added to {circle} by {author}" : "{external} is toegevoegd aan {circle} door {author}",
    "You accepted {member}'s request to join {circle}" : "Je accepteerde {member}'s verzoek op lid te worden van {circle}",
    "Your request to join {circle} has been accepted by {author}" : "Je verzoek om lid te worden van {circle} is door {author} geaccepteerd",
    "{member}'s request to join {circle} has been accepted by {author}" : "{member}'s verzoek om lid te worden van {circle} is door {author} geaccepteerd",
    "You left {circle}" : "Je hebt {circle} verlaten",
    "{member} left {circle}" : "{member} heeft {circle} verlaten",
    "You declined the invitation to join {circle}" : "Je hebt de uitnodiging om lid te worden van {circle} afgewezen",
    "{member} declined an invitation to join {circle}" : "{member} heeft de uitnodiging om lid te worden van {circle} afgewezen",
    "You cancelled your request to join {circle}" : "Je hebt je verzoek om lid te worden van {circle} ingetrokken",
    "{member} cancelled a request to join {circle}" : "{member}annuleerde een verzoek tot deelname aan {circle}",
    "You have been removed from {circle} by {author}" : "Je werd van {circle} door {author} verwijderd",
    "{member} has been removed from {circle} by {author}" : "{member} is van {circle} door {author} verwijderd",
    "You removed {external} from {circle}" : "Je hebt {external} verwijderd van {circle}",
    "{external} has been removed from {circle} by {author}" : "{external} is door {author} verwijderd van {circle} ",
    "You cancelled {member}'s invitation to join {circle}" : "Je hebt de uitnodiging voor {member} om lid te worden van {circle} ingetrokken",
    "Your invitation to join {circle} has been cancelled by {author}" : "Je uitnodiging om lid te worden van {circle} is door {author} ingetrokken",
    "{author} cancelled {member}'s invitation to join {circle}" : "{author} heeft de uitnodiging voor {member} om lid te worden van {circle} ingetrokken",
    "You dismissed {member}'s request to join {circle}" : "Je het het verzoek van {member}'s om lid te worden van {circle} afgewezen",
    "Your request to join {circle} has been dismissed by {author}" : "Je verzoek om bij {circle} aan te sluiten is door {author} afgewezen",
    "{member}'s request to join {circle} has been dismissed by {author}" : "{member}'s verzoek om lid te worden van {circle} is door {author} afgewezen",
    "You invited {member} to join {circle}" : "Je nodigde {member} uit om lid te worden van {circle}",
    "You have been invited to join {circle} by {author}" : "Je bent uitgenodigd om lid te worden van {circle} door {author}",
    "{member} has been invited to join {circle} by {author}" : "{member} is uitgenodigd om lid te worden van {circle} door {author}",
    "You changed {member}'s level in {circle} to %1$s" : "Je veranderde {member}'s niveau in {circle} naar %1$s",
    "{author} changed your level in {circle} to %1$s" : "{author} veranderde je niveau in {circle} naar %1$s",
    "{author} changed {member}'s level in {circle} to %1$s" : "{author} veranderde {member}'s niveau van {circle} naar %1$s",
    "You sent a request to join {circle}" : "Je verzoek gestuurd om lid te worden van {circle}",
    "{member} sent a request to join {circle}" : "{member} verzond een verzoek om lid te worden van {circle}",
    "You are the new owner of {circle}" : "Je bent de nieuwe eigenaar van {circle}",
    "{member} is the new owner of {circle}" : "{member} is de nieuwe eigenaar van {circle}",
    "Teams" : "Teams",
    "On events happening in a <strong>team</strong> of which you are a member" : "Over gebeurtenissen binnen een <strong>team</strong> waarvan jij deel uitmaakt",
    "Any important event in a <strong>team</strong> you are moderating" : "Elke belangrijke gebeurtenis in een <strong>team</strong> waarvan jij moderator bent",
    "On global events happening in any <strong>team</strong>" : "Over algemene gebeurtenissen binnen in elk <strong>team</strong>",
    "Single" : "Alleen",
    "Personal" : "Persoonlijk",
    "System" : "Systeem",
    "Visible" : "Zichtbaar",
    "Open" : "Open",
    "Invite" : "Uitnodigen",
    "Join request" : "Deelnameverzoek",
    "Friends" : "Vrienden",
    "Password protected" : "Wachtwoord-beveiligd",
    "No Owner" : "Geen eigenaar",
    "Hidden" : "Verborgen",
    "Backend" : "Backend",
    "Local" : "Lokaal",
    "Root" : "Root",
    "Team invite" : "Teamuitnodiging",
    "Federated" : "Gefedereerd",
    "Mount point" : "Aankoppelpunt",
    "Nextcloud Account" : "Nextcloud Account",
    "Nextcloud Group" : "Nextcloud Groep",
    "Email address" : "E-mailadres",
    "Contact" : "Contact",
    "Team" : "Team",
    "Nextcloud App" : "Nextcloud App",
    "Member" : "Lid",
    "Moderator" : "Moderator",
    "Admin" : "Beheerder",
    "Owner" : "Eigenaar",
    "%s shared »%s« with you." : "%sheeft \"%s\" met je gedeeld.",
    "%s shared »%s« with \"%s\"." : "%s deelde \"%s\" met \"%s\".",
    "%s on %s" : "%s op  %s",
    "%1$s shared »%2$s« with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s heeft \"%2$s\" met je gedeeld.\nJe moet al een aparte e-mail hebben ontvangen met een link om er te komen.\n",
    "%1$s shared »%2$s« with you. You should have already received a separate email with a link to access it." : "%1$s heeft \"%2$s\" met je gedeeld. Je moet al een aparte e-mail hebben ontvangen met een link om er te komen.",
    "Password to access »%1$s« shared to you by %2$s" : "Wachtwoord voor toegang tot \"%1$s\" met jou gedeeld door %2$s",
    "Password to access »%s«" : "Wachtwoord voor toegang \"%s\"",
    "It is protected with the following password:" : "Het is beveiligd met het volgende wachtwoord:",
    "%1$s via %2$s" : "%1$s via %2$s",
    "Click the button below to open it." : "Klik op de button hieronder om te openen.",
    "Open »%s«" : "Open \"%s\"",
    "%1$s shared multiple files with you.\nYou should have already received a separate email with a link to access them.\n" : "%1$s heeft verschillende bestanden met je gedeeld.\nJe moet al een aparte e-mail hebben ontvangen met een link om er te komen.\n",
    "%1$s shared multiple files with you. You should have already received a separate email with a link to access them." : "%1$s heeft verschillende bestanden met je gedeeld. Je moet al een aparte e-mail hebben ontvangen met een link om er te komen.",
    "Password to access files shared to you by %1$s" : "Wachtwoord voor toegang tot bestanden met jou gedeeld door %1$s",
    "Password to access files" : "Wachtwoord voor toegang tot bestanden",
    "%s shared multiple files with \"%s\"." : "%s deelde meerdere bestanden met \"%s\".",
    "%s shared multiple files with you." : "%s deelde meerdere bestanden met jou.",
    "Boot up" : "Opstarten",
    "Nextcloud Initialization" : "Nextcloud Initialisatie",
    "Circles App Initialization" : "Circles App Initialisatie",
    "Fresh installation status" : "Nieuwe installatiestatus",
    "Building Local Database" : "Aanmaken lokale database",
    "Adding local users and moderators" : "Toevoegen lokale gebruikers en moderatoren",
    "Show all teams" : "Geef alle teams weer",
    "Create a new team" : "Nieuw team aanmaken",
    "Files" : "Bestanden",
    "The team is not federated" : "Het team is niet gefedereerd",
    "You cannot join this team" : "Je kunt niet lid worden van dit team",
    "This member is not a moderator" : "Dit lid is geen moderator",
    "Insufficient privileges" : "Onvoldoende rechten",
    "This member does not exist" : "Dit lid bestaat niet",
    "This member is the owner of the team" : "Dit lid is eigenaar van dit team",
    "Level cannot be changed for this type of member" : "Het niveau van dit type lid kan niet veranderd worden.",
    "%s (Team owned by %s)" : "%s (Team met eigenaar %s)",
    "You are now a member of the Team \"%2$s\"" : "Je bent nu lid van team \"%2$s\"",
    "You have been invited by %1$s into the Team \"%2$s\"" : "Je bent door %1$s uitgenodigd bij het Team \"%2$s\".",
    "%1$s sent a request to be a member of the Team \"%2$s\"" : "%1$s stuurde een verzoek om lid te worden van het Team \"%2$s\"",
    "Accept" : "Accepteren",
    "Refuse" : "Weigeren",
    "Leave the team" : "Team verlaten",
    "%s" : "%s",
    "Personal team" : "Persoonlijk team",
    "%s owned by %s" : "%s is eigendom van %s",
    "You have no permission to create a new team" : "Je hebt geen machtiging om een nieuw team aan te maken",
    "%s shared a file with \"%s\"." : "%s deelde een bestand met \"%s\".",
    "%s shared a file with you." : "%s heeft een bestand met u gedeeld",
    "%1$s shared %2$s with %3$s" : "%1$s deelt %2$s met %3$s",
    "%1$s shared %2$s with \"%3$s\"" : "%1$s deelt %2$s met \"%3$s\"",
    "Open %s" : "%s openen",
    "%1$s shared some content with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s heeft enige informatie met je gedeeld.\nJe moet al een aparte e-mail hebben ontvangen met een link om er te komen.\n",
    "%1$s shared some content with you. You should have already received a separate email with a link to access it." : "%1$s heeft enige informatie met je gedeeld.\nJe moet al een aparte e-mail hebben ontvangen met een link om er te komen.",
    "Password to access content shared with you by %1$s" : "Wachtwoord om toegang te krijgen tot inhoud gedeeld met u door %1$s",
    "Password to access content" : "Wachtwoord voor toegang tot info",
    "This item is already shared with this team" : "Dit object is al gedeeld met dit team",
    "Bring cloud-users closer together." : "Breng cloudgebruikers dichter bij elkaar.",
    "Teams allows people to create their own groups of people/colleagues/friends.\nThose groups of people can then be used by any other app for sharing purpose." : "Teams stelt mensen in staat om hun eigen groepen van mensen/collega's/vrienden aan te maken. Deze groepen kunnen vervolgens door andere apps worden gebruikt om gegevens te delen.",
    "Failed to load teams" : "Teams laden is mislukt",
    "Try again" : "Probeer opnieuw",
    "No teams found" : "Geen teams gevonden",
    "Join or create teams to see them here." : "Sluit je aan bij een team of maak er een aan om ze hier te zien.",
    "Create your first team" : "Maak je eerste team",
    "Loading…" : "Laden…",
    "More teams" : "Meer teams",
    "No files in here" : "Hier geen bestanden",
    "No entries found in this folder" : "Niets in deze map gevonden",
    "Name" : "Naam",
    "Size" : "Omvang",
    "Modified" : "Gewijzigd",
    "Shared to Circles" : "Gedeeld met Kringen",
    "Testing Basic Circle Creation" : "Testen basis kringcreatie",
    "This feature is not available for personal circles" : "Deze functie is niet beschikbaar voor persoonlijke kringen",
    "You are already a member of this circle" : "Je bent al lid van deze kring",
    "You have been blocked from this circle" : "Je bent geblokkeerd van deze kring",
    "The account is already a member of this circle" : "Dit account is al lid van deze cirkel",
    "The account has already been invited into this circle" : "Dit account is al uitgenodigt voor deze cirkel"
},
"nplurals=2; plural=(n != 1);");
